
SET FOREIGN_KEY_CHECKS = 0;

-- ----------------------------------------------------------------------------
-- Table ActionPhoto
-- ----------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS `ActionPhoto` (
  `Id` INT NOT NULL AUTO_INCREMENT,
  `PhotoPath` VARCHAR(200) CHARACTER SET 'utf8mb4' NOT NULL,
  `RoadActionId` INT NOT NULL,
  PRIMARY KEY (`Id`),
  CONSTRAINT `FK_ActionPhoto_RoadAction`
    FOREIGN KEY (`RoadActionId`)
    REFERENCES `RoadAction` (`Id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION);

-- ----------------------------------------------------------------------------
-- Table ActionType
-- ----------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS `ActionType` (
  `Id` INT NOT NULL,
  `Name` VARCHAR(50) CHARACTER SET 'utf8mb4' NOT NULL,
  `BackColorHex` CHAR(7) CHARACTER SET 'utf8mb4' NOT NULL,
  `FontColorHex` CHAR(7) CHARACTER SET 'utf8mb4' NOT NULL,
  `IsEmergencyEvent` TINYINT(1) NOT NULL,
  PRIMARY KEY (`Id`));

-- ----------------------------------------------------------------------------
-- Table Branch
-- ----------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS `Branch` (
  `Id` INT NOT NULL AUTO_INCREMENT,
  `Name` VARCHAR(50) CHARACTER SET 'utf8mb4' NULL,
  `LocationLongitude` DECIMAL(9,6) NOT NULL,
  `LocationLatitude` DECIMAL(8,6) NOT NULL,
  PRIMARY KEY (`Id`));

-- ----------------------------------------------------------------------------
-- Table Driver
-- ----------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS `Driver` (
  `Id` INT NOT NULL AUTO_INCREMENT,
  `FullName` VARCHAR(100) CHARACTER SET 'utf8mb4' NOT NULL,
  `DateOfBirth` DATE NOT NULL,
  `Phone` VARCHAR(20) CHARACTER SET 'utf8mb4' NOT NULL,
  `Picture` LONGBLOB NULL,
  `MedicalHealthRestriction` INT NULL,
  PRIMARY KEY (`Id`));

-- ----------------------------------------------------------------------------
-- Table DriverOfTruck
-- ----------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS `DriverOfTruck` (
  `DriverId` INT NOT NULL,
  `TruckId` INT NOT NULL,
  PRIMARY KEY (`DriverId`, `TruckId`),
  CONSTRAINT `FK_DriverOfTruck_Driver`
    FOREIGN KEY (`DriverId`)
    REFERENCES `Driver` (`Id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `FK_DriverOfTruck_Truck`
    FOREIGN KEY (`TruckId`)
    REFERENCES `Truck` (`Id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION);

-- ----------------------------------------------------------------------------
-- Table LogisticsCenter
-- ----------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS `LogisticsCenter` (
  `BranchId` INT NOT NULL,
  `Address` VARCHAR(300) CHARACTER SET 'utf8mb4' NULL,
  PRIMARY KEY (`BranchId`),
  CONSTRAINT `FK_LogisticsCenter_Branch`
    FOREIGN KEY (`BranchId`)
    REFERENCES `Branch` (`Id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION);

-- ----------------------------------------------------------------------------
-- Table Parking
-- ----------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS `Parking` (
  `Id` INT NOT NULL AUTO_INCREMENT,
  `TruckParkId` INT NOT NULL,
  `TruckId` INT NOT NULL,
  `StartParking` DATETIME(6) NOT NULL,
  `EndParking` DATETIME(6) NULL,
  `ParkingSpaceColumn` CHAR(1) CHARACTER SET 'utf8mb4' NOT NULL,
  `ParkingSpaceRow` INT NOT NULL,
  PRIMARY KEY (`Id`),
  CONSTRAINT `FK_Parking_Truck`
    FOREIGN KEY (`TruckId`)
    REFERENCES `Truck` (`Id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `FK_Parking_TruckPark`
    FOREIGN KEY (`TruckParkId`)
    REFERENCES `TruckPark` (`BranchId`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION);

-- ----------------------------------------------------------------------------
-- Table RoadAction
-- ----------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS `RoadAction` (
  `Id` INT NOT NULL AUTO_INCREMENT,
  `ActionTypeId` INT NOT NULL,
  `StartDateTime` DATETIME(6) NOT NULL,
  `DriverId` INT NULL,
  `TransportTaskId` INT NOT NULL,
  `PlaceLongitude` DECIMAL(9,6) NULL,
  `PlaceLatitude` DECIMAL(8,6) NULL,
  `PlaceDescription` VARCHAR(100) CHARACTER SET 'utf8mb4' NULL,
  `Comment` VARCHAR(0) CHARACTER SET 'utf8mb4' NULL,
  PRIMARY KEY (`Id`),
  CONSTRAINT `FK_RoadAction_ActionType`
    FOREIGN KEY (`ActionTypeId`)
    REFERENCES `ActionType` (`Id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `FK_RoadAction_Driver`
    FOREIGN KEY (`DriverId`)
    REFERENCES `Driver` (`Id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `FK_RoadAction_TransportTask`
    FOREIGN KEY (`TransportTaskId`)
    REFERENCES `TransportTask` (`Id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION);

-- ----------------------------------------------------------------------------
-- Table TransportTask
-- ----------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS `TransportTask` (
  `Id` INT NOT NULL AUTO_INCREMENT,
  `CreatedDateTime` DATETIME(6) NOT NULL,
  `ArrivalLogisticsCenterId` INT NOT NULL,
  `DestinationLogisticsCenterId` INT NOT NULL,
  `Deadline` DATE NULL,
  `TruckId` INT NULL,
  `Comment` VARCHAR(0) CHARACTER SET 'utf8mb4' NULL,
  PRIMARY KEY (`Id`),
  CONSTRAINT `FK_TransportTask_LogisticsCenter`
    FOREIGN KEY (`ArrivalLogisticsCenterId`)
    REFERENCES `LogisticsCenter` (`BranchId`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `FK_TransportTask_LogisticsCenter1`
    FOREIGN KEY (`DestinationLogisticsCenterId`)
    REFERENCES `LogisticsCenter` (`BranchId`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `FK_TransportTask_Truck`
    FOREIGN KEY (`TruckId`)
    REFERENCES `Truck` (`Id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION);

-- ----------------------------------------------------------------------------
-- Table Truck
-- ----------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS `Truck` (
  `Id` INT NOT NULL AUTO_INCREMENT,
  `TruckModelId` INT NOT NULL,
  `Number` VARCHAR(10) CHARACTER SET 'utf8mb4' NOT NULL,
  `CurrentLocationLatitude` DECIMAL(8,6) NULL,
  `CurrentLocationLongitude` DECIMAL(9,6) NULL,
  `CompetitorId` INT NULL,
  PRIMARY KEY (`Id`),
  CONSTRAINT `FK_Truck_TruckModel`
    FOREIGN KEY (`TruckModelId`)
    REFERENCES `TruckModel` (`Id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION);

-- ----------------------------------------------------------------------------
-- Table TruckModel
-- ----------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS `TruckModel` (
  `Id` INT NOT NULL AUTO_INCREMENT,
  `Name` VARCHAR(50) CHARACTER SET 'utf8mb4' NOT NULL,
  `VendorId` INT NOT NULL,
  `TruckTypeId` INT NOT NULL,
  `TankVolume` INT NULL,
  `FuelConsumption` INT NULL,
  PRIMARY KEY (`Id`),
  CONSTRAINT `FK_TruckModel_TruckType`
    FOREIGN KEY (`TruckTypeId`)
    REFERENCES `TruckType` (`Id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `FK_TruckModel_TruckVendor`
    FOREIGN KEY (`VendorId`)
    REFERENCES `TruckVendor` (`Id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION);

-- ----------------------------------------------------------------------------
-- Table TruckPark
-- ----------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS `TruckPark` (
  `BranchId` INT NOT NULL,
  `ColumnsCount` INT NOT NULL,
  `RowsCount` INT NOT NULL,
  PRIMARY KEY (`BranchId`),
  CONSTRAINT `FK_TruckPark_Branch`
    FOREIGN KEY (`BranchId`)
    REFERENCES `Branch` (`Id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION);

-- ----------------------------------------------------------------------------
-- Table TruckType
-- ----------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS `TruckType` (
  `Id` INT NOT NULL AUTO_INCREMENT,
  `Name` VARCHAR(50) CHARACTER SET 'utf8mb4' NOT NULL,
  `Picture` LONGBLOB NOT NULL,
  PRIMARY KEY (`Id`));

-- ----------------------------------------------------------------------------
-- Table TruckVendor
-- ----------------------------------------------------------------------------
CREATE TABLE IF NOT EXISTS `TruckVendor` (
  `Id` INT NOT NULL AUTO_INCREMENT,
  `Name` VARCHAR(50) CHARACTER SET 'utf8mb4' NOT NULL,
  PRIMARY KEY (`Id`));

SET FOREIGN_KEY_CHECKS = 1;
